==> react-divcreator-2.0.10.tgz: package/Readme.md <==
# Website


## [http://react-divcreator.cba.pl](http://react-divcreator.cba.pl)


## [Documentation](http://react-divcreator.cba.pl/#/documentation)

# Available types
    
- [Accordion](http://react-divcreator.cba.pl/#/components/accordion)
- [Articles](http://react-divcreator.cba.pl/#/components/articles)

- Boxes

    - [BoxBoxes](http://react-divcreator.cba.pl/#/components/boxboxes)
    - [BoxMenu](http://react-divcreator.cba.pl/#/components/boxmenu)
    - [BoxWindow](http://react-divcreator.cba.pl/#/components/boxwindow)

- Buttons

    - [Buttons](http://react-divcreator.cba.pl/#/components/buttons)
    - [ButtonsNavigation](http://react-divcreator.cba.pl/#/components/buttonsnavigation)

- [Breadcrumbs](http://react-divcreator.cba.pl/#/components/breadcrumbs)

- [Cards](http://react-divcreator.cba.pl/#/components/cards)

- [Cube](http://react-divcreator.cba.pl/#/components/cube)

- [Dashboard](http://react-divcreator.cba.pl/#/components/dashboard)

- [Divtriangle](http://react-divcreator.cba.pl/#/components/divtriangle)

- [Fullscreenloading](http://react-divcreator.cba.pl/#/components/fullscreenloading)

- [Image](http://react-divcreator.cba.pl/#/components/image)

- Inputs

    - [Input](http://react-divcreator.cba.pl/#/components/input)

    - [InputList](http://react-divcreator.cba.pl/#/components/inputList)

    - [InputListSwitch](http://react-divcreator.cba.pl/#/components/inputlistswitch)

- [Links](http://react-divcreator.cba.pl/#/components/links)

- [List](http://react-divcreator.cba.pl/#/components/list)

- Animated menus

    - [MenuAnimationCustom](http://react-divcreator.cba.pl/#/components/menuanimationcustom)

    - [MenuAnimationDots](http://react-divcreator.cba.pl/#/components/menuanimationdots)

    - [MenuAnimationHamburger](http://react-divcreator.cba.pl/#/components/menuanimationhamburger)

    - [MenuAnimationSquare](http://react-divcreator.cba.pl/#/components/menuanimationsquare)

- Clickable menus

    - [MenuHorizontalClick](http://react-divcreator.cba.pl/#/components/menuhorizontalclick)

    - [MenuVerticalClick](http://react-divcreator.cba.pl/#/components/menuverticalclick)

- Fixed menus

    - [MenuFixedBottom](http://react-divcreator.cba.pl/#/components/menufixedbottom)

    - [MenuFixedLeft](http://react-divcreator.cba.pl/#/components/menufixedleft)

    - [MenuFixedRight](http://react-divcreator.cba.pl/#/components/menufixedright)

    - [MenuFixedTop](http://react-divcreator.cba.pl/#/components/menufixedtop)

- Hover menus

    - [MenuHorizontalHover](http://react-divcreator.cba.pl/#/components/menuhorizontalhover)

    - [MenuVerticalHover](http://react-divcreator.cba.pl/#/components/menuverticalhover)

- [Modal](http://react-divcreator.cba.pl/#/components/modal)

- [Paging](http://react-divcreator.cba.pl/#/components/paging)

- [Slider](http://react-divcreator.cba.pl/#/components/slider)

- [Sourcecode](http://react-divcreator.cba.pl/#/components/sourcecode)

- [Stars](http://react-divcreator.cba.pl/#/components/stars)

- [Verticalbars](http://react-divcreator.cba.pl/#/components/verticalbars)

- [Videobackground](http://react-divcreator.cba.pl/#/components/videobackground)


# [Changelog](http://react-divcreator.cba.pl/#/changelog)

version: v2.0.0
    
    Initialisation of the React-divcreators new version.
   
    
version: v2.0.1

    Added Readme.md file modules names.
   
    
version: v2.0.2

    Added new keys: triangleWH, contentBackgroundColor, headerBackgroundColor, triangleBackgroundColor to the BoxWindow module.
   
    
version: v2.0.3

    Added new key: allMatchesCallback to the SourceCode module.
   
    
version: v2.0.4

    Improved performance and matching quality of the SourceCode module.
   
    
version: v2.0.5
    
    Added new keys: removeLines, removeLinesChar to the SourceCode module. Added new key: animationType to the modules: MenuFixedBottom, MenuFixedLeft, MenuFixedRight and MenuFixedTop.
   
    
version: v2.0.6

    Improved toggling functionality for the buttons: maximize and minimize in the BoxWindow module.
   
    
version: v2.0.7

    Administrative tasks.
   
    
version: v2.0.8

    Added new modules: BoxMenu and Breadcrumbs.

version: v2.0.9

    Removed babel-polyfill from project.

version: v2.0.10

    Improved modlue: Slider (interactive part) and added mobile devices support for interactive sliding.

==> react-divcreator-2.0.16.tgz: package/Readme.md <==
# Website


## [http://react-divcreator.cba.pl](http://react-divcreator.cba.pl)


## [Documentation](http://react-divcreator.cba.pl/#/documentation)

## [NPM](https://github.com/janitzed/react-divcreator) 

# Available types
    
- [Accordion](http://react-divcreator.cba.pl/#/components/accordion)
- [Articles](http://react-divcreator.cba.pl/#/components/articles)

- Boxes

    - [BoxBoxes](http://react-divcreator.cba.pl/#/components/boxboxes)
    - [BoxMenu](http://react-divcreator.cba.pl/#/components/boxmenu)
    - [BoxWindow](http://react-divcreator.cba.pl/#/components/boxwindow)

- Buttons

    - [Buttons](http://react-divcreator.cba.pl/#/components/buttons)
    - [ButtonsNavigation](http://react-divcreator.cba.pl/#/components/buttonsnavigation)

- [Breadcrumbs](http://react-divcreator.cba.pl/#/components/breadcrumbs)

- [Cards](http://react-divcreator.cba.pl/#/components/cards)

- [Cube](http://react-divcreator.cba.pl/#/components/cube)

- [Dashboard](http://react-divcreator.cba.pl/#/components/dashboard)

- [Divtriangle](http://react-divcreator.cba.pl/#/components/divtriangle)

- [Fullscreenloading](http://react-divcreator.cba.pl/#/components/fullscreenloading)

- [Image](http://react-divcreator.cba.pl/#/components/image)

- Inputs

    - [Input](http://react-divcreator.cba.pl/#/components/input)

    - [InputList](http://react-divcreator.cba.pl/#/components/inputList)

    - [InputListSwitch](http://react-divcreator.cba.pl/#/components/inputlistswitch)

    - [InputSuggestion](http://react-divcreator.cba.pl/#/components/inputsuggestion)

- [Links](http://react-divcreator.cba.pl/#/components/links)

- [List](http://react-divcreator.cba.pl/#/components/list)

- Animated menus

    - [MenuAnimationCustom](http://react-divcreator.cba.pl/#/components/menuanimationcustom)

    - [MenuAnimationDots](http://react-divcreator.cba.pl/#/components/menuanimationdots)

    - [MenuAnimationHamburger](http://react-divcreator.cba.pl/#/components/menuanimationhamburger)

    - [MenuAnimationSquare](http://react-divcreator.cba.pl/#/components/menuanimationsquare)

- Clickable menus

    - [MenuHorizontalClick](http://react-divcreator.cba.pl/#/components/menuhorizontalclick)

    - [MenuVerticalClick](http://react-divcreator.cba.pl/#/components/menuverticalclick)

- Fixed menus

    - [MenuFixedBottom](http://react-divcreator.cba.pl/#/components/menufixedbottom)

    - [MenuFixedLeft](http://react-divcreator.cba.pl/#/components/menufixedleft)

    - [MenuFixedRight](http://react-divcreator.cba.pl/#/components/menufixedright)

    - [MenuFixedTop](http://react-divcreator.cba.pl/#/components/menufixedtop)

- Hover menus

    - [MenuHorizontalHover](http://react-divcreator.cba.pl/#/components/menuhorizontalhover)

    - [MenuVerticalHover](http://react-divcreator.cba.pl/#/components/menuverticalhover)

- [Modal](http://react-divcreator.cba.pl/#/components/modal)

- [Paging](http://react-divcreator.cba.pl/#/components/paging)

- [Slider](http://react-divcreator.cba.pl/#/components/slider)

- [Sourcecode](http://react-divcreator.cba.pl/#/components/sourcecode)

- [Stars](http://react-divcreator.cba.pl/#/components/stars)

- [Verticalbars](http://react-divcreator.cba.pl/#/components/verticalbars)

- [Videobackground](http://react-divcreator.cba.pl/#/components/videobackground)

- [website404](http://react-divcreator.cba.pl/#/components/website404)

# [Changelog](http://react-divcreator.cba.pl/#/changelog)

version: v2.0.0
    
    Initialisation of the React-divcreators new version.
   
    
version: v2.0.1

    Added Readme.md file modules names.
   
    
version: v2.0.2

    Added new keys: triangleWH, contentBackgroundColor, headerBackgroundColor, triangleBackgroundColor to the BoxWindow module.
   
    
version: v2.0.3

    Added new key: allMatchesCallback to the SourceCode module.
   
    
version: v2.0.4

    Improved performance and matching quality of the SourceCode module.
   
    
version: v2.0.5
    
    Added new keys: removeLines, removeLinesChar to the SourceCode module. Added new key: animationType to the modules: MenuFixedBottom, MenuFixedLeft, MenuFixedRight and MenuFixedTop.
   
    
version: v2.0.6

    Improved toggling functionality for the buttons: maximize and minimize to the BoxWindow module.
   
    
version: v2.0.7

    Administrative tasks.
   
    
version: v2.0.8

    Added new modules: BoxMenu and Breadcrumbs.

version: v2.0.9

    Removed babel-polyfill from project.

version: v2.0.10

    Improved module: Slider (interactive part) and added mobile devices support for interactive sliding.

version: v2.0.11

    Improved module: Slider (interactive part and css properties). Added new key: displayButtons. Removed unused keys: moveSliderSpeed, moveSliderLeft, moveSliderRight, moveSliderTop and moveSliderDown.

version: v2.0.12

    Improved module: Slider (interactive part in combination of active dots and prev next button).

version: v2.0.13

    Added new module: InputSuggestion. Added new key: animationType to the module: Accordion. 

version: v2.0.14

    Added new keys: sortAsc and sortDesc to the module InputSuggestion.

version: v2.0.15

    Added new keys: showAllSuggestionsOnFocus and mouseOverSelection to the module InputSuggestion.
    Added new key: sliderSpeed to the module Slider and improved case "moveSlider" while sliding with the mouse to the left and right site.
